'use strict';

/* If your code uses external modules, create instances here. - 外部モジュールを使う場合はここでインスタンスを生成してください。
   e.g.  const request = require('xxxx');   // xxxx : external module - xxxxは外部モジュール */
const axios = require('axios');

exports.handler = async event => {
  /* 
     Code for "warm start"
    The Riiiver system might call your Lambda function constantly to make it Warm Start.
    When the system called your function, the heavy modules are cached on the Lamba environment.
    The following code makes the (heavy) external module cached.
     ピースの実行速度高速化処理
    Lambda関数をウォームスタート状態にするために、このLambda関数は
    定期的にRiiiver System側からコールされることがあります。その際の処理をここで記述します。
    外部モジュールなどの重いインスタンスをキャッシュさせ、高速化します。*/
  if (event.call === 'lambda') {
    console.log('CALLED:LAMBDA');

    /* If you use the external modules, please code the following: - 外部モジュールを使う場合に記入してくだい。
       e.g.  if ( xxxx !== null ){} // xxxx: instance for the module.  -  xxxx : 生成したインスタンス */
    if (axios !== null) { }

    return;
  }

  /* Start coding here - これ以降にコードを記入してください。*/

  console.log('start: event = ', JSON.stringify(event));

  const apiHost = 'https://api.openweathermap.org';
  const apiPath = '/data/2.5/weather';
  const apikey = '98dxxxxxxxxxxxxxxxxxxxxxxxxxxx';    // ← insert your API key here. - ここに皆さんのAPI Keyを入れる
  let response = {
    status: 200,
    body: {
      celsiusTemperature: -50
    }
  };

  const cityName = event.properties.preferences.cityName;     // Get the location information entered by the user - 自分のpieceのプリファレンスの値
  const urlString = `${apiHost}${apiPath}?q=${cityName},jp&APPID=${apikey}`;  // Combine strings and make the URL - URLの文字列を完成させる。
  console.log('urlString: ', urlString);

  // Get weather information - 天気情報を取得
  let weatherData = await getWeatherInfo(urlString);

  //　Get today's weather information - 天気情報から今日の情報を取得
  if (weatherData) {
    const tempK = weatherData.main.temp;           // Save the temperature in the obtained JSON. The unit is Kelvin. - REST APIから得られたJSON内の温度を保存。単位はケルビン。
    response.body.celsiusTemperature = tempK - 273.15;  // The value sent to the next block will be the temperature in Celsius (Number) - 次のブロックに返す値は摂氏で数値(Number)
  }

  console.log('output: ', response);

  return response;
};

function getWeatherInfo(urlString) {
  console.log('getWeatherInfo: start');
  
  const options ={
    url : urlString,
    method : 'get',
  }

  return axios.request(options)
  .then(function (response) {
    console.log('getWeatherInfo: response.data = ',JSON.stringify(response.data));
    return response.data;
  })
  .catch(function(error){
    console.error('getWeatherInfo: response = ', JSON.stringify(error));
    return null;
  });
}